==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
var ChaikinOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinOscillatorIndicatorDescriptionMetadata, _super);
    function ChaikinOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
            ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.k(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ab(ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.d = function (a) {
        ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
        a.ad("ChaikinOscillatorIndicator", function () { return new ChaikinOscillatorIndicatorDescription(); });
        a.ac("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
}(Base));
export { ChaikinOscillatorIndicatorDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
var ChaikinOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinOscillatorIndicatorDescriptionMetadata, _super);
    function ChaikinOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
            ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.k(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.d = function (a) {
        ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
        a.ae("ChaikinOscillatorIndicator", function () { return new ChaikinOscillatorIndicatorDescription(); });
        a.ad("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
    };
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
}(Base));
export { ChaikinOscillatorIndicatorDescriptionMetadata };
